Match records in consecutive stages with different matching conditions. Each set of linked records are assigned a unique identifier with relevant group-level information.
record_group(df, ..., to_s4 = TRUE)record_group() is superseded. Moving forward, please use links.